@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.testing import INTEGRATION_TESTING
-from Products.CMFPlone.utils import getToolByName
+from Products.CMFCore.utils import getToolByName
 
 import unittest
 
 
 class TestToolsView(unittest.TestCase):
-    """Tests the global tools view.
-    """
+    """Tests the global tools view."""
 
     layer = INTEGRATION_TESTING
 
