@@ -1,36 +1,28 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.links.viewlets import RSSViewlet
 from plone.app.layout.viewlets.tests.base import ViewletsTestCase
+from plone.app.testing import setRoles
+from plone.app.testing import TEST_USER_ID
+from plone.base.interfaces import ISiteSyndicationSettings
 from plone.registry.interfaces import IRegistry
-from Products.CMFPlone.interfaces.syndication import ISiteSyndicationSettings
 from zope.component import getUtility
 
 
 class TestRSSViewletView(ViewletsTestCase):
-    """
-    Test the document by line viewlet
-    """
-
-    def afterSetUp(self):
-        pass
-
     def test_RSSViewlet(self):
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
+        self.portal.invokeFactory("Folder", "news")
         registry = getUtility(IRegistry)
         settings = registry.forInterface(ISiteSyndicationSettings)
         if settings.allowed:
             # make sure syndication is disabled
-            self.loginAsPortalOwner()
             settings.allowed = False
-            self.logout()
         request = self.app.REQUEST
         viewlet = RSSViewlet(self.portal, request, None, None)
         viewlet.update()
         result = viewlet.render()
-        self.assertEqual(result.strip(), '')
-        self.loginAsPortalOwner()
+        self.assertEqual(result.strip(), "")
         settings.allowed = True
         settings.site_rss_items = (self.portal.news.UID(),)
-        self.logout()
         request = self.app.REQUEST
         viewlet = RSSViewlet(self.portal, request, None, None)
         viewlet.update()
