@@ -1,19 +1,9 @@
-# -*- coding: utf-8 -*-
-from zope.deferredimport import deprecated
 from zope.interface import Attribute
 from zope.interface import Interface
 
 
-# remove in plone 6
-deprecated(
-    "Import from Products.CMFPlone instead",
-    IDefaultPage="Products.CMFPlone.interfaces.defaultpage:DefaultPage",
-)
-
-
 class INavigationRoot(Interface):
-    """A marker interface for signaling the navigation root.
-    """
+    """A marker interface for signaling the navigation root."""
 
 
 class INavigationQueryBuilder(Interface):
@@ -23,7 +13,7 @@ class INavigationQueryBuilder(Interface):
 
     def __call__():
         """Returns a mapping describing a catalog query used to build a
-           navigation structure.
+        navigation structure.
         """
 
 
